
ArconaiAudio
============

Allows you to listen to Arconai through your terminal

Installation
------------

.. code-block:: bash

       pip3 install --user ArconaiAudio

Dependencies
------------

You need to install ``mpv`` as well

Usage
-----

In your terminal, run

.. code-block:: bash

   ArconaiAudio
